==> jc-1.4.0.tar.gz: polyglot/util/Enum__24EnumKey.h <==
// class polyglot.util.Enum$EnumKey

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 59f8c2703b7d9265 polyglot_util_Enum__24EnumKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_Enum__24EnumKey_H_
#define _JC_polyglot_util_Enum__24EnumKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Enum$object;

// Typedefs
typedef struct _jc_polyglot_util_Enum__24EnumKey$sub_refs	_jc_polyglot_util_Enum__24EnumKey$sub_refs;
typedef struct _jc_polyglot_util_Enum__24EnumKey$sub_nonrefs	_jc_polyglot_util_Enum__24EnumKey$sub_nonrefs;
typedef struct _jc_polyglot_util_Enum__24EnumKey$refs	_jc_polyglot_util_Enum__24EnumKey$refs;
typedef struct _jc_polyglot_util_Enum__24EnumKey$nonrefs	_jc_polyglot_util_Enum__24EnumKey$nonrefs;
typedef struct _jc_polyglot_util_Enum__24EnumKey$object	_jc_polyglot_util_Enum__24EnumKey$object;

typedef const struct _jc_polyglot_util_Enum__24EnumKey$vmethods	_jc_polyglot_util_Enum__24EnumKey$vmethods;
typedef const struct _jc_polyglot_util_Enum__24EnumKey$vtable	_jc_polyglot_util_Enum__24EnumKey$vtable;
typedef const struct _jc_polyglot_util_Enum__24EnumKey$vtype	_jc_polyglot_util_Enum__24EnumKey$vtype;

// Constructors
extern void _jc_polyglot_util_Enum__24EnumKey$method$_init$06745444b46c631a(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *, struct _jc_polyglot_util_Enum$object *);

// Virtual methods
extern jboolean _jc_polyglot_util_Enum__24EnumKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_polyglot_util_Enum__24EnumKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Enum__24EnumKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_Enum__24EnumKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_util_Enum__24EnumKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_util_Enum__24EnumKey$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_util_Enum__24EnumKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *);
};

// Vtable
struct _jc_polyglot_util_Enum__24EnumKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum__24EnumKey$vmethods	polyglot_util_Enum__24EnumKey;
};

// Vtype
struct _jc_polyglot_util_Enum__24EnumKey$vtype {
	_jc_type			type;
	_jc_polyglot_util_Enum__24EnumKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Enum__24EnumKey$sub_refs {
	struct _jc_polyglot_util_Enum$object	*e;
};

// Reference instance fields (object)
struct _jc_polyglot_util_Enum__24EnumKey$refs {
    _jc_polyglot_util_Enum__24EnumKey$sub_refs	polyglot_util_Enum__24EnumKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Enum__24EnumKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Enum__24EnumKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum__24EnumKey$sub_nonrefs	polyglot_util_Enum__24EnumKey;
};

// Object instance structure
struct _jc_polyglot_util_Enum__24EnumKey$object {
	_jc_polyglot_util_Enum__24EnumKey$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Enum__24EnumKey$vtype	*vtype;
	_jc_polyglot_util_Enum__24EnumKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Enum__24EnumKey$vtype _jc_polyglot_util_Enum__24EnumKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Enum__24EnumKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Enum__24EnumKey$class_object;

#endif	/* _JC_polyglot_util_Enum__24EnumKey_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/Enum__24EnumKey.h <==
// class polyglot.util.Enum$EnumKey

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 59f8c2703b7d9265 polyglot_util_Enum__24EnumKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_Enum__24EnumKey_H_
#define _JC_polyglot_util_Enum__24EnumKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Enum$object;

// Typedefs
typedef struct _jc_polyglot_util_Enum__24EnumKey$sub_refs	_jc_polyglot_util_Enum__24EnumKey$sub_refs;
typedef struct _jc_polyglot_util_Enum__24EnumKey$sub_nonrefs	_jc_polyglot_util_Enum__24EnumKey$sub_nonrefs;
typedef struct _jc_polyglot_util_Enum__24EnumKey$refs	_jc_polyglot_util_Enum__24EnumKey$refs;
typedef struct _jc_polyglot_util_Enum__24EnumKey$nonrefs	_jc_polyglot_util_Enum__24EnumKey$nonrefs;
typedef struct _jc_polyglot_util_Enum__24EnumKey$object	_jc_polyglot_util_Enum__24EnumKey$object;

typedef const struct _jc_polyglot_util_Enum__24EnumKey$vmethods	_jc_polyglot_util_Enum__24EnumKey$vmethods;
typedef const struct _jc_polyglot_util_Enum__24EnumKey$vtable	_jc_polyglot_util_Enum__24EnumKey$vtable;
typedef const struct _jc_polyglot_util_Enum__24EnumKey$vtype	_jc_polyglot_util_Enum__24EnumKey$vtype;

// Constructors
extern void _jc_polyglot_util_Enum__24EnumKey$method$_init$06745444b46c631a(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *, struct _jc_polyglot_util_Enum$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_util_Enum__24EnumKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_Enum__24EnumKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_Enum__24EnumKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_Enum__24EnumKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_util_Enum__24EnumKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_util_Enum__24EnumKey$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_util_Enum__24EnumKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_util_Enum__24EnumKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_Enum__24EnumKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum__24EnumKey$vmethods	polyglot_util_Enum__24EnumKey;
};

// Vtype
struct _jc_polyglot_util_Enum__24EnumKey$vtype {
	_jc_type			type;
	_jc_polyglot_util_Enum__24EnumKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Enum__24EnumKey$sub_refs {
	struct _jc_polyglot_util_Enum$object	*e;
};

// Reference instance fields (object)
struct _jc_polyglot_util_Enum__24EnumKey$refs {
    _jc_polyglot_util_Enum__24EnumKey$sub_refs	polyglot_util_Enum__24EnumKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Enum__24EnumKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Enum__24EnumKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum__24EnumKey$sub_nonrefs	polyglot_util_Enum__24EnumKey;
};

// Object instance structure
struct _jc_polyglot_util_Enum__24EnumKey$object {
	_jc_polyglot_util_Enum__24EnumKey$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Enum__24EnumKey$vtype	*vtype;
	_jc_polyglot_util_Enum__24EnumKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Enum__24EnumKey$vtype _jc_polyglot_util_Enum__24EnumKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Enum__24EnumKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Enum__24EnumKey$class_object;

#endif	/* _JC_polyglot_util_Enum__24EnumKey_H_ */
